Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4813)

Unified Diff: chrome/browser/ui/ash/launcher/launcher_favicon_loader.cc

Issue 2823133002: Clean up some ash constants. (Closed)
Patch Set: ditto Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/ash/launcher/launcher_favicon_loader.cc
diff --git a/chrome/browser/ui/ash/launcher/launcher_favicon_loader.cc b/chrome/browser/ui/ash/launcher/launcher_favicon_loader.cc
index 974fa1b5bc88f711a18e9af038fc8bc65c3a2535..4562bf0486bcb58d259447452202ab060d62ab63 100644
--- a/chrome/browser/ui/ash/launcher/launcher_favicon_loader.cc
+++ b/chrome/browser/ui/ash/launcher/launcher_favicon_loader.cc
@@ -21,7 +21,7 @@ const int kMaxBitmapSize = 256;
////////////////////////////////////////////////////////////////////////////////
// FaviconRawBitmapHandler fetchs all bitmaps with the 'icon' (or 'shortcut
// icon') link tag, storing the one that best matches ash::SHELF_SIZE. These
// icon bitmaps are not resized and are not cached beyond the lifetime of the
// class. Bitmaps larger than kMaxBitmapSize are ignored.
@@ -144,7 +144,7 @@ void FaviconRawBitmapHandler::AddFavicon(const GURL& image_url,
if (new_bitmap.height() > kMaxBitmapSize ||
new_bitmap.width() > kMaxBitmapSize)
return;
- if (new_bitmap.height() < ash::GetShelfConstant(ash::SHELF_SIZE))
+ if (new_bitmap.height() < ash::kShelfSize)
return;
if (!bitmap_.isNull()) {
// We want the smallest icon that is large enough.
@@ -21,7 +21,7 @@ const int kMaxBitmapSize = 256;
////////////////////////////////////////////////////////////////////////////////
// FaviconRawBitmapHandler fetchs all bitmaps with the 'icon' (or 'shortcut
-// icon') link tag, storing the one that best matches ash::SHELF_SIZE. These
+// icon') link tag, storing the one that best matches ash::kShelfSize. These
// icon bitmaps are not resized and are not cached beyond the lifetime of the
// class. Bitmaps larger than kMaxBitmapSize are ignored.
« no previous file with comments | « chrome/browser/ui/apps/chrome_app_delegate.cc ('k') | chrome/browser/ui/ash/launcher/launcher_favicon_loader_browsertest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698